Crate oliver

Crate oliver 

Re-exports

pub use larian_formats;

Enums

DataFileType
Specifies the type of data file.

Functions

contents
Lists the file paths contained in the mod file.
convert
Converts a single file from from one type to another.
convert_all
Recursively converts all files from one type to another in the given directory and its subdirectories.
extract_file
Extracts a single file from a mod.
pack
Packs the loose mod files in the given directory into an LSPK file.
parse
Parses the given paths, printing LSPK metadata if verbose is enabled.
unpack
Unpacks the given LSPK file into loose mod files.